/**
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "Features/FeaturePack.h"

#include <opencv2/core.hpp>

namespace MediaVision {
namespace Image {

FeaturePack::FeaturePack() :
		__keypointsType(KT_INVALID),
		__objectKeypoints(),
		__descriptorsType(DT_INVALID),
		__objectDescriptors(),
		__recognitionRate(0.f)
{
	; /* NULL */
}

FeaturePack::FeaturePack(const FeaturePack& copy) :
		__keypointsType(copy.__keypointsType),
		__objectKeypoints(copy.__objectKeypoints),
		__descriptorsType(copy.__descriptorsType),
		__objectDescriptors(copy.__objectDescriptors.clone()),
		__recognitionRate(copy.__recognitionRate)
{
	; /* NULL */
}

FeaturePack& FeaturePack::operator= (const FeaturePack& copy)
{
	if (this != &copy) {
		__keypointsType = copy.__keypointsType;
		__objectKeypoints = copy.__objectKeypoints;
		__descriptorsType = copy.__descriptorsType;
		__objectDescriptors = copy.__objectDescriptors.clone();
		__recognitionRate = copy.__recognitionRate;
	}

	return *this;
}

} /* Image */
} /* MediaVision */
